/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package logic;

import org.apache.log4j.Logger;

import visual.gui.TraceViewPanel;

/**
 * A trace viel panel controller controlling the trace view panel allowing the user to change the current trace view layout.
 * 
 * @author pdo
 * 
 */
public class TraceViewPanelController {
	
	// =========================== Attributes =================================

	/** A logger to log relevant actions in this class. */
	private static final Logger LOGGER = Logger.getLogger(TraceViewPanelController.class);

	/** The trace view panel currently being controlled by this controller. */
	private TraceViewPanel panel;
	
	// ========================== Constructor =================================

	/**
	 * Creates a new {@link TraceViewPanelController} instance. This class is not intended for instantiation from outside of this package.
	 */
	protected TraceViewPanelController() {}

	// ============================ Methods ===================================
	
	/**
	 * Initializes this {@link TraceViewPanelController} instance with the {@link TraceViewPanel} object to control.
	 * 
	 * @param viewPanel
	 *            The trace view panel to be controlled by this controller.
	 * @throws IllegalArgumentException
	 *             If the trace view panel passed in is {@code null}.
	 */
	public void init(final TraceViewPanel viewPanel) throws IllegalArgumentException {

		if (viewPanel == null) {
			throw new IllegalArgumentException("You cannot control a null trace view panel");
		}

		this.panel = viewPanel;
	}

	/**
	 * Rebuilds the entire {@link TraceViewPanel} instance currently being controlled by this controller. This method has no effect, if there is no such trace view
	 * panel.
	 */
	public void rebuild() {

		if (this.panel == null) {
			LOGGER.warn("You cannot rebuild a null trace view panel.");
		} else {
			this.panel.rebuild();
		}
	}
}
