/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package utils.comparators;

import java.util.Comparator;

import javax.swing.tree.DefaultMutableTreeNode;

import data.dynamics.STraceEvent;

import utils.NodeObject;

/**
 * A custom comparator to compare two {@link DefaultMutableTreeNode} objects by the trace Id (primary) and the order index (secondary) of their {@link STraceEvent}
 * user objects. Applying this comparator to a list of such nodes will sort this list according to a non-decreasing trace Id (primary) and non-decreasing order index
 * (secondary) of its members' user objects.
 * 
 * @author pdo
 * 
 */
public class JTreeNodeByTraceComparator implements Comparator<DefaultMutableTreeNode> {

	// ========================== Constructor =================================

	/**
	 * Creates a new {@link JTreeNodeByTinComparator} instance.
	 */
	public JTreeNodeByTraceComparator() {}

	// ============================ Methods ===================================

	@Override
	public int compare(final DefaultMutableTreeNode node1, final DefaultMutableTreeNode node2) throws IllegalArgumentException {

		if (node1 == null || node2 == null) {
			throw new IllegalArgumentException("You cannot compare null elements.");
		}
		
		final STraceEvent event1 = ((NodeObject) node1.getUserObject()).getTraceEvent();
		final STraceEvent event2 = ((NodeObject) node2.getUserObject()).getTraceEvent();

		int retval = Long.compare(event1.getTrace().getTraceId(), event2.getTrace().getTraceId());
		if (retval == 0) {
			retval = Long.compare(event1.getOrderIndex(), event2.getOrderIndex());
		}
		
		return retval;
	}

}
