/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package utils.comparators;

import java.util.Comparator;

import data.dynamics.STrace;

/**
 * A custom comparator to compare two {@link STrace} objects by their execution entry timestamp (tin). Applying this comparator to a list of such elements will sort
 * that list according to a non-decreasing tin attribute value of its members.
 * 
 * @author pdo
 * 
 */
public class SThreadComparator implements Comparator<STrace> {

	// ========================== Constructor =================================

	/**
	 * Creates a new {@link SThreadComparator} instance.
	 */
	public SThreadComparator() {}

	// ============================ Methods ===================================

	@Override
	public int compare(final STrace thread1, final STrace thread2) throws IllegalArgumentException {

		if (thread1 == null || thread2 == null) {
			throw new IllegalArgumentException("You cannot compare null elements.");
		}
		
		return Long.compare(thread1.getTin(), thread2.getTin());
	}

}
