/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package utils.comparators;

import java.util.Comparator;

import data.dynamics.STraceEvent;

/**
 * A custom comparator to compare two {@link STraceEvent} objects by their execution entry timestamp (tin) (primary criterion) and their order index (secondary
 * criterion). Applying this comparator to a list of such elements will sort this list according to a non-decreasing tin and order index attribute value of its
 * members.
 * 
 * @author pdo
 * 
 */
public final class SThreadEventComparator implements Comparator<STraceEvent> {

	// ========================== Constructor =================================

	/**
	 * Creates a new {@link SThreadEventComparator} instance.
	 */
	public SThreadEventComparator() {}

	// ============================ Methods ===================================

	@Override
	public int compare(final STraceEvent event1, final STraceEvent event2) throws IllegalArgumentException {

		if (event1 == null || event2 == null) {
			throw new IllegalArgumentException("You cannot compare null elements.");
		}
		
		int retval = Long.compare(event1.getTin(), event2.getTin());

		if (retval == 0) {
			retval = Long.compare(event1.getTrace().getTraceId(), event2.getTrace().getTraceId());
		}
		
		if (retval == 0) {
			retval = Long.compare(event1.getOrderIndex(), event2.getOrderIndex());
		}

		return retval;
	}

}
