/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package utils.comparators;

import java.util.Comparator;

import data.dynamics.STrace;

/**
 * A custom {@link Comparator} class comparing two {@link STrace} instances by their thread id (primary) and their tin attribute (secondary). Applying this
 * comparator to a list of traces will result in a list whose members are sorted by their thread id in descending order. If there are two traces with the same thread
 * id, their order is determined by their tin attribute in descending order.
 * 
 * @author pdo
 * 
 */
public class STraceByThreadIdComparator implements Comparator<STrace> {

	// ============================= Constructor ==============================

	/**
	 * Creates a new {@link STraceByThreadIdComparator} instance.
	 */
	public STraceByThreadIdComparator() {/* nothing to do */}

	// =============================== Methods ================================

	@Override
	public int compare(final STrace trace1, final STrace trace2) throws IllegalArgumentException {

		if (trace1 == null || trace2 == null) {
			throw new IllegalArgumentException("You cannot compare null traces.");
		}

		int retval = Long.compare(trace1.getThreadId(), trace2.getThreadId());

		if (retval == 0) {
			retval = Long.compare(trace1.getTin(), trace2.getTin());
		}

		return retval;
	}

}
