/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package visual.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;

import configuration.Language;



import logic.Logic;

/**
 * The panel displaying the properties of a selected element in the current visualization or trace view.
 * 
 * @author pdo
 * 
 */
public class PropertiesPanel extends JPanel {

	// =========================== Attributes =================================

	/** The generated {@code serialVersionUID} for serialization. */
	private static final long serialVersionUID = -5736820049666185188L;

	/** The table model all table contents are being added to. */
	private final DefaultTableModel tableModel = new DefaultTableModel();

	// ========================== Constructor =================================

	/**
	 * Constructs a new {@link PropertiesPanel} instance.
	 */
	public PropertiesPanel() {

		super();
		this.createComponents();
		this.setPreferredSize(new Dimension(0, 160));
		this.setMinimumSize(this.getPreferredSize());

		// initialize controller
		Logic.getInstance().getPropertiesController().init(this.tableModel);
	}

	// ============================ Methods ===================================

	/**
	 * Creates all components of this {@link PropertiesPanel} and adds it to this component.
	 */
	private void createComponents() {

		// set up table model
		this.tableModel.setColumnCount(2);
		this.tableModel.setColumnIdentifiers(new String[] { Language.getInstance().get("properties.identifier.column1"),
			Language.getInstance().get("properties.identifier.column2"), });
		
		// set layout
		this.setLayout(new BorderLayout());
		final JTable table = new JTable(this.tableModel);
		table.setEnabled(false); // make table not selectable or editable
		this.add(new JScrollPane(table));
	}

}
