/***************************************************************************
 * This file is part of Synchrovis - A prototypical implementation of the 
 * visualization approach described in the author's master's thesis titled 
 * 			
 * 							 Visualisierung von 
 * 					Synchronisationspunkten in Kombination 
 * 						  mit der Statik und Dynamik 
 *							 eines Softwaresystems
 *
 * written at Software Engineering Group, Department of Computer Science at 
 * Christian-Albrechts-University of Kiel.
 * 
 * Author: Philipp Dhring, October 2012
 ***************************************************************************/

package visual.gui;

import java.awt.Dimension;

import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellEditor;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeSelectionModel;

import logic.Logic;

/**
 * A trace tree view to visualize all trace elements currently imported from Kieker trace files in arranged as a tree.
 * 
 * @author pdo
 * 
 */
public final class TraceTreeView extends JScrollPane {
	
	// =========================== Attributes =================================

	/** The generated {@code serialVersionUID} for serialization. */
	private static final long serialVersionUID = -8858237204399848064L;

	/** The underlying {@link JTree} of this trace view all trace elements of the currently visible trace are going to be added to. */
	private final JTree tree;
	
	// ========================== Constructor =================================
	
	/**
	 * Constructs a new {@link TraceTreeView} instance and initializes the {@link TraceTreeViewController} singleton instance with this object.
	 */
	public TraceTreeView() {

		super();
		final DefaultTreeModel model = new DefaultTreeModel(new DefaultMutableTreeNode());
		this.tree = new JTree(model);
		
		this.configureTree();
		this.setViewportView(this.tree);
		this.setPreferredSize(new Dimension(300, 710));
		this.setMinimumSize(new Dimension(300, 0));
		Logic.getInstance().getTreeViewController().init(this.tree, model);
	}
	
	// ============================ Methods ===================================

	/**
	 * Configures this trace tree view. It setups the tree cell renderer, cell editor, and selection behavior in the underlying tree.
	 */
	private void configureTree() {

		// set tree and selection properties
		this.tree.setRootVisible(false);
		this.tree.setShowsRootHandles(true);
		this.tree.setEditable(true);
		this.tree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);

		// setup renderer
		final DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
		renderer.setOpenIcon(renderer.getDefaultLeafIcon());
		renderer.setClosedIcon(renderer.getDefaultLeafIcon());
		renderer.setIcon(renderer.getDefaultLeafIcon());

		// setup editor
		this.tree.setCellRenderer(renderer);
		this.tree.setCellEditor(new DefaultTreeCellEditor(this.tree, (DefaultTreeCellRenderer) this.tree.getCellRenderer()));
		this.tree.addTreeSelectionListener(new TreeSelectionListener() {

			@Override
			public void valueChanged(final TreeSelectionEvent event) {
				Logic.getInstance().getTreeViewController().handleTreeSelection();
			}
		});
	}

}
